# define docker elasticsearch container name
BVX_PYTEST_DOCKER_ES_CONTAINER_NAME = "pytest_elasticsearch"

# define docker elasticsearch image name
BVX_PYTEST_DOCKER_ES_IMAGE_NAME = "elasticsearch:7.14.2"

# define docker elasticsearch port name key
BVX_PYTEST_DOCKER_ES_HOST_ENV_KEY = "BVX_PYTEST_ES_HOST"

# define docker elasticsearch port name key
BVX_PYTEST_DOCKER_ES_PORT_ENV_KEY = "BVX_PYTEST_ES_PORT"

# define docker elasticsearch port name key
BVX_PYTEST_ES_DSN = "elasticsearch+http://{0}:{1}/"

# EOF
